@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::InitTarget;
 
-our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2019-09-18'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,19 +20,19 @@ different configuration.
 
 _
     participants => [
-        {name=>"default" ,
+        {name=>"1k default" ,
          code_template => 'use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; for(1..1000) { Log::ger::init_target(package =>"main") }'},
-        {name=>"with LGO:Screen" ,
+        {name=>"1k with LGO:Screen" ,
          code_template => 'use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Screen"); for(1..1000) { Log::ger::init_target(package => "main") }'},
-        {name=>"with LGO:File" ,
+        {name=>"1k with LGO:File" ,
          code_template => 'use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'.qq('$fname').'); for(1..1000) { Log::ger::init_target(package => "main") }'},
-        {name=>"with LGO:Composite (0 outputs)" ,
+        {name=>"1k with LGO:Composite (0 outputs)" ,
          code_template => 'use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite"); for(1..1000) { Log::ger::init_target(package => "main") }'},
-        {name=>"with LGO:Composite (Screen)" ,
+        {name=>"1k with LGO:Composite (Screen)" ,
          code_template => 'use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}}); for(1..1000) { Log::ger::init_target(package => "main") }'},
-        {name=>"with LGO:Composite (Screen+File)" ,
+        {name=>"1k with LGO:Composite (Screen+File)" ,
          code_template => 'use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'.qq('$fname').'}}}); for(1..1000) { Log::ger::init_target(package => "main") }'},
-        {name=>"with LGO:Composite (Screen+File & pattern layouts)" ,
+        {name=>"1k with LGO:Composite (Screen+File & pattern layouts)" ,
          code_template => 'use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'.qq('$fname').'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }'},
     ],
     precision => 7,
@@ -53,7 +53,7 @@ Bencher::Scenario::LogGer::InitTarget - Benchmark init_target()
 
 =head1 VERSION
 
-This document describes version 0.014 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.015 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2019-09-18.
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 =over
 
-=item * default (perl_code)
+=item * 1k default (perl_code)
 
 Code template:
 
@@ -83,7 +83,7 @@ Code template:
 
 
 
-=item * with LGO:Screen (perl_code)
+=item * 1k with LGO:Screen (perl_code)
 
 Code template:
 
@@ -91,15 +91,15 @@ Code template:
 
 
 
-=item * with LGO:File (perl_code)
+=item * 1k with LGO:File (perl_code)
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/ljRni0BSz4'); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/S8HoF53EXq'); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
-=item * with LGO:Composite (0 outputs) (perl_code)
+=item * 1k with LGO:Composite (0 outputs) (perl_code)
 
 Code template:
 
@@ -107,7 +107,7 @@ Code template:
 
 
 
-=item * with LGO:Composite (Screen) (perl_code)
+=item * 1k with LGO:Composite (Screen) (perl_code)
 
 Code template:
 
@@ -115,19 +115,19 @@ Code template:
 
 
 
-=item * with LGO:Composite (Screen+File) (perl_code)
+=item * 1k with LGO:Composite (Screen+File) (perl_code)
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/ljRni0BSz4'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/S8HoF53EXq'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
-=item * with LGO:Composite (Screen+File & pattern layouts) (perl_code)
+=item * 1k with LGO:Composite (Screen+File & pattern layouts) (perl_code)
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/ljRni0BSz4'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/S8HoF53EXq'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -135,22 +135,22 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.2 >>, OS kernel: I<< Linux version 4.8.0-53-generic >>.
+Run on: perl: I<< v5.26.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.3 >>, OS kernel: I<< Linux version 4.10.0-38-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::InitTarget >>):
 
  #table1#
- +----------------------------------------------------+-----------+-----------+------------+-----------+---------+
- | participant                                        | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +----------------------------------------------------+-----------+-----------+------------+-----------+---------+
- | with LGO:Composite (Screen+File & pattern layouts) |      2.8  |       360 |       1    |   0.0012  |       7 |
- | default                                            |      2.85 |       350 |       1.03 | 8.8e-05   |       7 |
- | with LGO:Composite (Screen+File)                   |      2.99 |       335 |       1.07 |   0.0002  |       8 |
- | with LGO:Composite (Screen)                        |      4.02 |       249 |       1.45 |   0.00012 |       7 |
- | with LGO:File                                      |      5.3  |       190 |       1.9  |   0.00023 |       7 |
- | with LGO:Composite (0 outputs)                     |      7.42 |       135 |       2.67 |   0.00011 |       7 |
- | with LGO:Screen                                    |      7.44 |       134 |       2.67 | 2.5e-05   |       7 |
- +----------------------------------------------------+-----------+-----------+------------+-----------+---------+
+ +-------------------------------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                                           | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-------------------------------------------------------+-----------+-----------+------------+---------+---------+
+ | 1k with LGO:Composite (0 outputs)                     |      2.5  |       390 |        1   | 0.00056 |       8 |
+ | 1k with LGO:Composite (Screen+File & pattern layouts) |      2.8  |       360 |        1.1 | 0.00086 |       7 |
+ | 1k default                                            |      2.8  |       360 |        1.1 | 0.00097 |       7 |
+ | 1k with LGO:Composite (Screen+File)                   |      3    |       340 |        1.2 | 0.0016  |       7 |
+ | 1k with LGO:Composite (Screen)                        |      4    |       250 |        1.6 | 0.00057 |       9 |
+ | 1k with LGO:File                                      |      6.08 |       164 |        2.4 | 0.00016 |       7 |
+ | 1k with LGO:Screen                                    |      8.3  |       120 |        3.3 | 0.00026 |       7 |
+ +-------------------------------------------------------+-----------+-----------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -177,7 +177,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
