@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2019-09-18'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -124,7 +124,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.014 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.015 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2019-09-18.
 
 =head1 SYNOPSIS
 
@@ -142,27 +142,27 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::Any> 1.707
+L<Log::Any> 1.705
 
-L<Log::Contextual> 0.007001
+L<Log::Contextual> 0.008001
 
-L<Log::Contextual::SimpleLogger> 0.007001
+L<Log::Contextual::SimpleLogger> 0.008001
 
-L<Log::Dispatch> 2.65
+L<Log::Dispatch> 2.67
 
-L<Log::Dispatch::Null> 2.65
+L<Log::Dispatch::Null> 2.67
 
 L<Log::Dispatchouli> 2.015
 
-L<Log::Fast> v2.0.0
+L<Log::Fast> v2.0.1
 
 L<Log::Log4perl> 1.49
 
 L<Log::Log4perl::Tiny> 1.4.0
 
-L<Log::ger> 0.025
+L<Log::ger> 0.028
 
-L<Log::ger::Plugin::MultilevelLog> 0.025
+L<Log::ger::Plugin::MultilevelLog> 0.028
 
 L<Log::ger::Plugin::OptAway> 0.006
 
@@ -320,33 +320,33 @@ Command line:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.2 >>, OS kernel: I<< Linux version 4.8.0-53-generic >>.
+Run on: perl: I<< v5.26.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.3 >>, OS kernel: I<< Linux version 4.10.0-38-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
 
  #table1#
- +------------------------------------------+-----------+--------+------------+-----------+---------+
- | participant                              | rate (/s) |   time | vs_slowest |  errors   | samples |
- +------------------------------------------+-----------+--------+------------+-----------+---------+
- | Log::Dispatch::Null-100k_debug           |      0.59 | 1.7    |        1   |   0.0039  |       6 |
- | Log::Contextual+Log4perl-100k_trace      |      1.5  | 0.66   |        2.6 |   0.0046  |       6 |
- | Log::Contextual+SimpleLogger-100k_trace  |      1.5  | 0.65   |        2.6 |   0.0032  |       6 |
- | Mojo::Log-100k_debug                     |      3.1  | 0.32   |        5.3 |   0.0014  |       6 |
- | Log::Dispatchouli-100k_debug             |      5    | 0.2    |        8   |   0.0023  |       6 |
- | Log::Log4perl::Tiny-100k_trace           |      7.3  | 0.14   |       13   |   0.00044 |       6 |
- | Log::Fast-100k_is_debug                  |     10    | 0.08   |       20   |   0.00087 |       6 |
- | Log::Any-null_adapter-100k_log_trace     |     13    | 0.079  |       22   |   0.00025 |       7 |
- | Log::Log4perl-easy-100k_trace            |     14    | 0.069  |       25   |   0.00012 |       6 |
- | Log::Any-no_adapter-100k_is_trace        |     20    | 0.06   |       30   |   0.00097 |       6 |
- | Log::Any-null_adapter-100k_is_trace      |     20    | 0.06   |       30   |   0.0007  |       9 |
- | Log::Fast-100k_DEBUG                     |     20    | 0.05   |       40   |   0.00071 |       6 |
- | Log::Any-no_adapter-100k_log_trace       |     30    | 0.03   |       60   |   0.00037 |       6 |
- | Log::ger+LGP:OptAway-100k_log_trace      |     44.8  | 0.0223 |       76.5 |   4e-06   |       6 |
- | Log::ger+LGP:MutilevelLog-100k_log_6     |     45    | 0.022  |       77   | 9.8e-05   |       7 |
- | Log::ger+LGP:MutilevelLog-100k_log_trace |     46    | 0.022  |       79   |   0.00016 |       6 |
- | Log::ger-100k_log_is_trace               |     59    | 0.017  |      100   | 7.9e-05   |       6 |
- | Log::ger-100k_log_trace                  |     59    | 0.017  |      100   | 1.7e-05   |       6 |
- +------------------------------------------+-----------+--------+------------+-----------+---------+
+ +------------------------------------------+-----------+-------+------------+-----------+---------+
+ | participant                              | rate (/s) |  time | vs_slowest |  errors   | samples |
+ +------------------------------------------+-----------+-------+------------+-----------+---------+
+ | Log::Dispatch::Null-100k_debug           |       0.5 | 2     |        1   |   0.096   |       6 |
+ | Log::Contextual+Log4perl-100k_trace      |       2   | 0.6   |        4   |   0.009   |       7 |
+ | Log::Contextual+SimpleLogger-100k_trace  |       1.9 | 0.53  |        4.1 |   0.0045  |       6 |
+ | Mojo::Log-100k_debug                     |       3.6 | 0.28  |        7.9 |   0.0023  |       6 |
+ | Log::Dispatchouli-100k_debug             |       6   | 0.2   |       10   |   0.0024  |       8 |
+ | Log::Log4perl::Tiny-100k_trace           |       7   | 0.1   |       20   |   0.0051  |       6 |
+ | Log::Any-null_adapter-100k_log_trace     |      14   | 0.07  |       31   |   0.00013 |       6 |
+ | Log::Fast-100k_is_debug                  |      14   | 0.069 |       32   |   0.00018 |       6 |
+ | Log::Log4perl-easy-100k_trace            |      17   | 0.058 |       38   |   0.0002  |       7 |
+ | Log::Any-null_adapter-100k_is_trace      |      20   | 0.05  |       40   |   0.00074 |       7 |
+ | Log::Any-no_adapter-100k_is_trace        |      21   | 0.048 |       46   |   0.00028 |       7 |
+ | Log::Fast-100k_DEBUG                     |      20   | 0.04  |       50   |   0.00076 |       6 |
+ | Log::Any-no_adapter-100k_log_trace       |      38   | 0.026 |       85   |   0.0002  |       6 |
+ | Log::ger+LGP:OptAway-100k_log_trace      |      49   | 0.02  |      110   | 5.1e-05   |       6 |
+ | Log::ger+LGP:MutilevelLog-100k_log_trace |      50   | 0.02  |      110   | 2.2e-05   |       6 |
+ | Log::ger+LGP:MutilevelLog-100k_log_6     |      50   | 0.02  |      110   | 3.2e-05   |       6 |
+ | Log::ger-100k_log_is_trace               |      70   | 0.02  |      100   |   0.00055 |       7 |
+ | Log::ger-100k_log_trace                  |      67   | 0.015 |      150   |   0.00014 |       6 |
+ +------------------------------------------+-----------+-------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -373,7 +373,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
