@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::OutputStartup;
 
-our $DATE = '2018-12-20'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2019-09-18'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 use 5.010001;
 use strict;
@@ -75,7 +75,7 @@ Bencher::Scenario::LogGer::OutputStartup
 
 =head1 VERSION
 
-This document describes version 0.014 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
+This document describes version 0.015 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2019-09-18.
 
 =head1 SYNOPSIS
 
@@ -97,27 +97,27 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Output::Array> 0.025
+L<Log::ger::Output::Array> 0.028
 
 L<Log::ger::Output::ArrayRotate> 0.001
 
 L<Log::ger::Output::Callback> 0.004
 
-L<Log::ger::Output::Composite> 0.007
+L<Log::ger::Output::Composite> 0.009
 
 L<Log::ger::Output::DirWriteRotate> 0.002
 
-L<Log::ger::Output::File> 0.006
+L<Log::ger::Output::File> 0.007
 
 L<Log::ger::Output::FileWriteRotate> 0.002
 
 L<Log::ger::Output::LogAny> 0.006
 
-L<Log::ger::Output::Null> 0.025
+L<Log::ger::Output::Null> 0.028
 
-L<Log::ger::Output::Screen> 0.007
+L<Log::ger::Output::Screen> 0.008
 
-L<Log::ger::Output::String> 0.025
+L<Log::ger::Output::String> 0.028
 
 L<Log::ger::Output::Syslog> 0.001
 
@@ -277,7 +277,7 @@ L<Log::ger::Output::Syslog>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.2 >>, OS kernel: I<< Linux version 4.8.0-53-generic >>.
+Run on: perl: I<< v5.26.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.3 >>, OS kernel: I<< Linux version 4.10.0-38-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
 
@@ -285,54 +285,54 @@ Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
  +---------------------------+-----------+-----------+------------+-----------+---------+
  | participant               | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
  +---------------------------+-----------+-----------+------------+-----------+---------+
- | init-with-FileWriteRotate |        21 |      47   |        1   |   0.00012 |      20 |
- | init-with-Syslog          |        31 |      33   |        1.4 | 7.6e-05   |      21 |
- | init-with-LogAny          |        49 |      20   |        2.3 |   0.00016 |      21 |
- | init-with-Composite       |        55 |      18   |        2.6 | 5.3e-05   |      21 |
- | init-with-DirWriteRotate  |        59 |      17   |        2.8 | 3.6e-05   |      21 |
- | init-with-Screen          |        74 |      13   |        3.5 | 3.2e-05   |      20 |
- | init-with-File            |        75 |      13   |        3.5 | 4.7e-05   |      20 |
- | init-with-String          |        75 |      13   |        3.5 | 3.3e-05   |      22 |
- | init-with-ArrayRotate     |        75 |      13   |        3.5 | 4.2e-05   |      20 |
- | init-with-Array           |        76 |      13   |        3.5 | 2.2e-05   |      20 |
- | init-with-Callback        |        77 |      13   |        3.6 | 3.4e-05   |      20 |
- | init-with-Null            |        78 |      13   |        3.6 | 1.4e-05   |      20 |
- | load-Screen               |        84 |      12   |        3.9 | 4.7e-05   |      20 |
- | load-Composite            |       110 |       9.2 |        5.1 | 3.2e-05   |      20 |
- | load-Syslog               |       120 |       8.4 |        5.6 | 2.5e-05   |      20 |
- | load-File                 |       120 |       8.3 |        5.6 | 2.3e-05   |      20 |
- | load-Callback             |       120 |       8.3 |        5.6 | 4.1e-05   |      20 |
- | load-FileWriteRotate      |       120 |       8.2 |        5.7 | 5.3e-05   |      20 |
- | load-String               |       120 |       8.2 |        5.7 |   2e-05   |      20 |
- | load-Array                |       120 |       8.2 |        5.7 | 4.8e-05   |      20 |
- | load-DirWriteRotate       |       120 |       8.2 |        5.7 | 2.6e-05   |      20 |
- | load-ArrayRotate          |       120 |       8.1 |        5.7 |   3e-05   |      20 |
- | load-LogAny               |       120 |       8.1 |        5.8 | 2.3e-05   |      20 |
- | load-Null                 |       170 |       5.8 |        8   | 4.1e-05   |      20 |
- | baseline                  |       180 |       5.5 |        8.4 | 3.3e-05   |      20 |
+ | init-with-Syslog          |      10.6 |     94.4  |       1    | 7.3e-05   |      20 |
+ | init-with-ArrayRotate     |      24.7 |     40.4  |       2.34 | 2.1e-05   |      20 |
+ | init-with-Callback        |      24.7 |     40.4  |       2.34 | 3.7e-05   |      20 |
+ | init-with-FileWriteRotate |      25   |     40    |       2.3  | 7.9e-05   |      23 |
+ | load-Composite            |      28.2 |     35.4  |       2.66 | 1.6e-05   |      20 |
+ | init-with-String          |      33   |     30    |       3.1  |   0.00022 |      30 |
+ | load-Syslog               |      43   |     23    |       4.1  | 2.7e-05   |      20 |
+ | load-Callback             |      44   |     22.7  |       4.15 | 2.2e-05   |      20 |
+ | load-ArrayRotate          |      44   |     22.7  |       4.16 | 1.6e-05   |      20 |
+ | init-with-LogAny          |      54   |     18    |       5.1  | 2.7e-05   |      20 |
+ | init-with-Composite       |      60   |     17    |       5.6  | 2.9e-05   |      20 |
+ | init-with-DirWriteRotate  |      65   |     15    |       6.1  | 2.6e-05   |      20 |
+ | init-with-Screen          |      74   |     13.5  |       6.99 | 3.8e-06   |      20 |
+ | init-with-File            |      74   |     14    |       7    | 2.5e-05   |      20 |
+ | init-with-Array           |      75.1 |     13.3  |       7.09 | 8.3e-06   |      20 |
+ | init-with-Null            |      76   |     13    |       7.2  | 1.6e-05   |      20 |
+ | load-Screen               |      89   |     11    |       8.4  | 1.5e-05   |      21 |
+ | load-File                 |     120   |      8.5  |      11    | 1.3e-05   |      20 |
+ | load-LogAny               |     120   |      8.4  |      11    | 3.4e-05   |      20 |
+ | load-String               |     120   |      8.4  |      11    | 1.8e-05   |      20 |
+ | load-FileWriteRotate      |     120   |      8.3  |      11    | 1.5e-05   |      20 |
+ | load-Array                |     120   |      8.3  |      11    | 1.6e-05   |      20 |
+ | load-DirWriteRotate       |     121   |      8.27 |      11.4  | 7.8e-06   |      20 |
+ | load-Null                 |     160   |      6.4  |      15    | 2.1e-05   |      20 |
+ | baseline                  |     160   |      6.2  |      15    | 1.3e-05   |      20 |
  +---------------------------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::OutputStartup --module-startup >>):
 
  #table2#
- +-----------------------------------+-----------+------------------------+------------+---------+---------+
- | participant                       | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +-----------------------------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Output::Screen          |      12   |                    6.5 |        1   | 2.8e-05 |      20 |
- | Log::ger::Output::Composite       |       9.5 |                    4   |        1.3 | 3.2e-05 |      21 |
- | Log::ger::Output::File            |       8.8 |                    3.3 |        1.4 | 4.5e-05 |      20 |
- | Log::ger::Output::DirWriteRotate  |       8.6 |                    3.1 |        1.4 | 5.1e-05 |      20 |
- | Log::ger::Output::FileWriteRotate |       8.4 |                    2.9 |        1.4 | 4.1e-05 |      20 |
- | Log::ger::Output::Callback        |       8.4 |                    2.9 |        1.4 | 6.7e-05 |      21 |
- | Log::ger::Output::LogAny          |       8.3 |                    2.8 |        1.4 | 3.9e-05 |      20 |
- | Log::ger::Output::ArrayRotate     |       8.2 |                    2.7 |        1.4 | 3.1e-05 |      21 |
- | Log::ger::Output::Syslog          |       8.2 |                    2.7 |        1.5 | 2.1e-05 |      20 |
- | Log::ger::Output::Array           |       8.2 |                    2.7 |        1.5 | 3.2e-05 |      20 |
- | Log::ger::Output::String          |       8.1 |                    2.6 |        1.5 | 2.3e-05 |      20 |
- | Log::ger::Output::Null            |       5.9 |                    0.4 |        2   | 5.5e-05 |      21 |
- | perl -e1 (baseline)               |       5.5 |                    0   |        2.2 | 4.1e-05 |      20 |
- +-----------------------------------+-----------+------------------------+------------+---------+---------+
+ +-----------------------------------+-----------+------------------------+------------+-----------+---------+
+ | participant                       | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +-----------------------------------+-----------+------------------------+------------+-----------+---------+
+ | Log::ger::Output::Composite       |      13   |                    6.8 |        1   |   0.00012 |      21 |
+ | Log::ger::Output::Screen          |      11   |                    4.8 |        1.1 | 2.2e-05   |      21 |
+ | Log::ger::Output::File            |       8.5 |                    2.3 |        1.5 | 1.5e-05   |      20 |
+ | Log::ger::Output::DirWriteRotate  |       8.4 |                    2.2 |        1.5 | 1.2e-05   |      20 |
+ | Log::ger::Output::Syslog          |       8.4 |                    2.2 |        1.5 | 1.4e-05   |      20 |
+ | Log::ger::Output::LogAny          |       8.3 |                    2.1 |        1.5 | 2.4e-05   |      21 |
+ | Log::ger::Output::ArrayRotate     |       8.3 |                    2.1 |        1.5 | 1.6e-05   |      20 |
+ | Log::ger::Output::FileWriteRotate |       8.3 |                    2.1 |        1.5 | 2.1e-05   |      20 |
+ | Log::ger::Output::Callback        |       8.3 |                    2.1 |        1.5 | 1.3e-05   |      20 |
+ | Log::ger::Output::Array           |       8.3 |                    2.1 |        1.5 | 1.3e-05   |      20 |
+ | Log::ger::Output::String          |       8.3 |                    2.1 |        1.5 | 1.1e-05   |      20 |
+ | Log::ger::Output::Null            |       6.5 |                    0.3 |        2   | 1.4e-05   |      20 |
+ | perl -e1 (baseline)               |       6.2 |                    0   |        2.1 | 1.2e-05   |      20 |
+ +-----------------------------------+-----------+------------------------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -359,7 +359,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
